==> haskell-yesod-default-1.2.0-184-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-6vMX0lSWKzQ45S3eqWdD6H
key: yesod-default-1.2.0-6vMX0lSWKzQ45S3eqWdD6H
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
author: Patrick Brisbin
exposed: True
indefinite: False
exposed-modules:
    Yesod.Default.Ignore
abi: bc0a98160cb17eeb85a075302b4f67a3
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-6vMX0lSWKzQ45S3eqWdD6H
depends:
    base-4.10.0.0 yesod-core-1.4.36-9Wuvli4twNl1FYy4owepkD
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             yesod-core-1.4.36-9Wuvli4twNl1FYy4owepkD=e7c2adabda951849baef438e4f90ac27
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-default-1.2.0-185-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-2GRJx8yBIKNK0z4AGnN8NS
key: yesod-default-1.2.0-2GRJx8yBIKNK0z4AGnN8NS
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
author: Patrick Brisbin
exposed: True
indefinite: False
exposed-modules:
    Yesod.Default.Ignore
abi: 7ad07182381d0b26ebaf0ae392b6a761
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-2GRJx8yBIKNK0z4AGnN8NS
depends:
    base-4.10.0.0 yesod-core-1.4.36-CCubKzflnITBeki6j2HPwK
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             yesod-core-1.4.36-CCubKzflnITBeki6j2HPwK=4276ebe75d7fa628f8776a933e49a52f
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
